#--
# Copyright (C) 2021 - Octopus Lab SAS
# All rights are described by the GPLv3 license present in the file /LICENSE available in the
# original repository of this file or [here](https://www.gnu.org/licenses/gpl-3.0.fr.html).
#++
# frozen_string_literal: true

# The GouvCalendarCompilator Module
# Compiles School Holidays Data and National Days Off data from Government sources into a new dataset
# and returns it as an Array of Hashes
module GouvCalendarCompilator
  YEAR_START = 2020
  public_constant :YEAR_START
  YEAR_END = (::Date.today.year + 1)
  public_constant :YEAR_END
  SCHOOL_HOLIDAYS_DATA_URL = 'https://www.data.gouv.fr/fr/datasets/r/000ae493-9fa8-4088-9f53-76d375204036'
  public_constant :SCHOOL_HOLIDAYS_DATA_URL
  DAYS_OFF_API_BASE_URL = 'https://calendrier.api.gouv.fr/jours-feries/'
  public_constant :DAYS_OFF_API_BASE_URL

  DAYS_OFF_ZONES_MATCHING = {
    guadeloupe: ['Guadeloupe'],
    guyane: ['Guyane'],
    'la-reunion': ['Réunion'],
    martinique: ['Martinique'],
    mayotte: ['Mayotte'],
    metropole: ['Zone A', 'Zone B', 'Zone C', 'Corse'],
    'nouvelle-caledonie': ['Nouvelle Calédonie'],
    'polynesie-francaise': ['Polynésie'],
    'saint-pierre-et-miquelon': ['Saint Pierre et Miquelon'],
    'wallis-et-futuna': ['Wallis et Futuna']
  }.freeze

  public_constant :DAYS_OFF_ZONES_MATCHING

  OPERATING_DAY = 0
  public_constant :OPERATING_DAY
  SCHOOL_HOLIDAYS = 1
  public_constant :SCHOOL_HOLIDAYS
  NATIONAL_DAY_OFF = 2
  public_constant :NATIONAL_DAY_OFF
  WEEK_END = 3
  public_constant :WEEK_END

  DATETIME_START = ::Date.parse("#{::GouvCalendarCompilator::YEAR_START}-01-01T00:00:00").freeze
  public_constant :DATETIME_START
  DATETIME_END = ::Date.parse("#{::GouvCalendarCompilator::YEAR_END}-12-31T23:59:59").freeze
  public_constant :DATETIME_END
  ONE_SECOND = (1.0 / (60 * 24 * 24))
  public_constant :ONE_SECOND
  # Base error class for all of the errors raised by this library.
  class Error < StandardError; end

  # Error related to bad argument given to a method.
  class ArgumentError < Error; end
end

require 'gouv_calendar_compilator/data_compilator'
require 'gouv_calendar_compilator/data_fetcher'
require 'gouv_calendar_compilator/data_compilators/france/school_holidays_data_compilator'
require 'gouv_calendar_compilator/data_compilators/france/national_days_off_data_compilator'
require 'gouv_calendar_compilator/zone_department_matching/france'
